<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Editor di canali della modalità</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Canali disponibili</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Canali della modalità</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="122"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Estensione non riconosciuta: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="150"/>
        <source>Fixture loading failed</source>
        <translation>Errore nel caricamento del Fixture</translation>
    </message>
    <message>
        <location filename="app.cpp" line="151"/>
        <source>Unable to load fixture definition: </source>
        <translation>Impossibile caricare la definizione della fixture: </translation>
    </message>
    <message>
        <location filename="app.cpp" line="245"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="app.cpp" line="246"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="251"/>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <location filename="app.cpp" line="252"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="257"/>
        <source>&amp;Save</source>
        <translation>&amp;Salvare</translation>
    </message>
    <message>
        <location filename="app.cpp" line="258"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="263"/>
        <source>Save &amp;As...</source>
        <translation>Salva &amp;Con Nome...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="264"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="269"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
    <message>
        <location filename="app.cpp" line="270"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="276"/>
        <source>Index</source>
        <translation>Indice</translation>
    </message>
    <message>
        <location filename="app.cpp" line="277"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="282"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Informazioni sull&apos;Editor di Fixture...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="287"/>
        <source>About Qt...</source>
        <translation>Informazioni su QT...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="314"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="app.cpp" line="324"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="app.cpp" line="362"/>
        <source>Open a fixture definition</source>
        <translation>Apri un file-Fixture</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Asistente per le Proprietà</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Valori</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Valore DMX di-partenza</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Numeri di valori per proprietà</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Quantità</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Numero di proprietà da creare</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>Nome comune per tutte le proprietà. Usa # per creare un numero corrente.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Proprietà #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Esempio</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Lista delle proprietà che devono essere create con questi parametri</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Modifica canale</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Rilevata sovrapposizione di valori. Prego correggere.&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation>Valore predefinito</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation>Preset</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Il nome di questo canale</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation>Ruolo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation>Colore 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation>Colore 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation>Valore 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation>Valore 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>Il gruppo a cui appartiene questo canale</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Immagine</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Grossolano (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Fine (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Funzionalità</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Minimum value</source>
        <translation>Valore minimo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Maximum value</source>
        <translation>Valore massimo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Rimuovi la funzionalità selezionata</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Assistente per le proprietà</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="92"/>
        <source>Edit Channel: </source>
        <translation>Modifica canale: </translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="480"/>
        <source>Overlapping values</source>
        <translation>Valori in soprapposizione</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="497"/>
        <source>Open Gobo File</source>
        <translation>Apri file di gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="500"/>
        <source>Gobo pictures</source>
        <translation>Immagini gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="614"/>
        <source>Missing resources</source>
        <translation>Risorse mancanti</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Some gobos are missing:

</source>
        <translation>Alcuni gobo non sono stati trovati:

</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Alcune proprietà non possono essere create in quanto ci sono valori in sovrapposizione.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Modifica Testa</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Canale</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Editor della modalità</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Nome della modalità</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="161"/>
        <source>Number</source>
        <translation>Numero</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="166"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="79"/>
        <source>Add channel(s) to this mode</source>
        <translation>Aggiungi canali a questa modalità</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="59"/>
        <source>Remove the selected channel</source>
        <translation>Rimuove il canale selezionato</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="99"/>
        <source>Raise the selected channel</source>
        <translation>Sposta in su il canale selezionato</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="119"/>
        <source>Lower the selected channel</source>
        <translation>Sposta in giù il canale selezionato</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="171"/>
        <source>Acts On</source>
        <translation>Agisce su</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="193"/>
        <source>Heads</source>
        <translation>Teste</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Head</source>
        <translation>Testa</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="214"/>
        <source>Compose a new head</source>
        <translation>Componi una nuova testa</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="234"/>
        <source>Remove the selected head</source>
        <translation>Rimuovi la testa selezionata</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="254"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Modifica il canale che appartiene alla testa selezionata</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="274"/>
        <source>Raise the selected head</source>
        <translation>Sposta su la testa selezionata</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="294"/>
        <source>Lower the selected head</source>
        <translation>Sposta in giù la testa selezionata</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="328"/>
        <source>Physical</source>
        <translation>Fisico</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="338"/>
        <source>Use global settings</source>
        <translation>Usa le impostazioni globali</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="348"/>
        <source>Override global settings</source>
        <translation>Usa al posto delle impostazioni globali</translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Lampada</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumens</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Temperatura colore (K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Peso</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>Kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Altezza</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Profondità</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation>Testa(e)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Lente</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Gradi minimi</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Gradi massimi</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Gradi max Pan</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Gradi max Tilt</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation>Disposizione (Colonne x Righe)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Elettrico</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Consumo</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>Connettore DMX</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Copia le informazioni fisiche negli appunti</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Incolla le informazioni fisiche dagli appunti</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Produttore</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>Nome del fabbricante di questo proiettore (es.:Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Modello</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>Nome del proiettore (es.:MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>Tipo di proiettore</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Autore</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <oldsource>The author name of this fixture definition</oldsource>
        <translation>Nome dell&apos;autore di questa definizione di Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Aggiungi un canale</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Rimuovere il canale selezionato</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Edita il canale selezionato</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Copia il canale selezionato in memoria</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Incolla il canale selezionato dalla memoria a questo proiettore</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Apri/Chiudi tutti i canali</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Teste</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Aggiungi una modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Rimuovere la modalità selezionata</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Edita la modalità selezionata</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Crea una copia della modalità selezionata</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Apri/Chiudi tutte le modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation>In modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation>Aggiungi un nuovo alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation>con</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation>sostituisci</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation>Canale di base</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation>Canale sostitutivo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation>Rimuovi gli alias selezionati</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation>Fisico</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="206"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Vuoi salvare tutti i cambiamenti al Fixture
&quot;%1&quot;
prima di chiudere?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="236"/>
        <location filename="fixtureeditor.cpp" line="246"/>
        <source>Missing important information</source>
        <translation>Mancano informazioni importanti</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Manca il nome del produttore.
Impossibile Salvare.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Manca il nome del modello.
Impossibile Salvare.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="277"/>
        <location filename="fixtureeditor.cpp" line="336"/>
        <source>Fixture saving failed</source>
        <translation>Salvataggio Fixture Fallito</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Unable to save fixture definition:
%1</source>
        <oldsource>Unable to save fixture definition: </oldsource>
        <translation>Impossibile salvare questo Fixture:
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="293"/>
        <source>Save fixture definition</source>
        <translation>Salva Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="370"/>
        <source>New Fixture</source>
        <translation>Nuova Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="447"/>
        <location filename="fixtureeditor.cpp" line="545"/>
        <source>Channel already exists</source>
        <translation>Il canale già esiste</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="546"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>il canale &quot;%1&quot; già esiste!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="455"/>
        <location filename="fixtureeditor.cpp" line="552"/>
        <source>Channel has no name</source>
        <translation>Canale senza nome</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="553"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Devi dare al canale un nome descrittivo!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="493"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Sei sicuro di vuoler rimuovere il canale: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="824"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Sei sicuro di voler rimuovere la modalità: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="665"/>
        <location filename="fixtureeditor.cpp" line="700"/>
        <location filename="fixtureeditor.cpp" line="937"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="666"/>
        <location filename="fixtureeditor.cpp" line="702"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="667"/>
        <location filename="fixtureeditor.cpp" line="704"/>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <location filename="fixtureeditor.cpp" line="706"/>
        <location filename="fixtureeditor.cpp" line="943"/>
        <source>Remove</source>
        <translation>Eliminare</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="679"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="777"/>
        <location filename="fixtureeditor.cpp" line="786"/>
        <source>Unable to add mode</source>
        <translation>Impossibile aggiungere modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="778"/>
        <source>Another mode by that name already exists</source>
        <translation>Esiste già una modalità con questo stesso nome</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="787"/>
        <source>You must give a name to the mode</source>
        <translation>Devi dare un nome alla modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="823"/>
        <source>Remove Mode</source>
        <translation>Elimina Modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="883"/>
        <source>Rename new mode</source>
        <translation>Rinomina nuova Modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="884"/>
        <source>Give a unique name for the mode</source>
        <translation>Inserisci un nome unico per la modalità</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="886"/>
        <source>Copy of %1</source>
        <translation>Copia di %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="896"/>
        <source>Invalid name</source>
        <translation>Nome Invalido</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="897"/>
        <source>Another mode by that name already exists.</source>
        <translation>Esiste già una modalità con questo nome.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="940"/>
        <source>Clone</source>
        <translation>Clona</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="948"/>
        <source>Modes</source>
        <translation>Modalità</translation>
    </message>
</context>
</TS>
